VmbChunkAccessCallback

Type Alias VmbChunkAccessCallback 

pub type VmbChunkAccessCallback = Option<unsafe extern "C" fn(featureAccessHandle: VmbHandle_t, userContext: *mut c_void) -> VmbError_t>;
\brief Function pointer type to access chunk data

This function should complete as quickly as possible, since it blocks other updates on the remote device.

This function should not throw exceptions, even if VmbC is used from C++. Any exception thrown will only result in an error code indicating that an exception was thrown.

\param[in] featureAccessHandle A special handle that can be used for accessing features; the handle is only valid during the call of the function. \param[in] userContext The value the user passed to ::VmbChunkDataAccess.

\return An error to be returned from ::VmbChunkDataAccess in the absence of other errors; A custom exit code >= ::VmbErrorCustom can be returned to indicate a failure via ::VmbChunkDataAccess return code

Aliased Type

pub enum VmbChunkAccessCallback {
    None,
    Some(unsafe extern "C" fn(*mut c_void, *mut c_void) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, *mut c_void) -> i32)

Some value of type T.