#[repr(C)]pub struct VmbFrame {Show 15 fields
pub buffer: *mut c_void,
pub bufferSize: VmbUint32_t,
pub context: [*mut c_void; 4],
pub receiveStatus: VmbFrameStatus_t,
pub frameID: VmbUint64_t,
pub timestamp: VmbUint64_t,
pub imageData: *mut VmbUint8_t,
pub receiveFlags: VmbFrameFlags_t,
pub pixelFormat: VmbPixelFormat_t,
pub width: VmbImageDimension_t,
pub height: VmbImageDimension_t,
pub offsetX: VmbImageDimension_t,
pub offsetY: VmbImageDimension_t,
pub payloadType: VmbPayloadType_t,
pub chunkDataPresent: VmbBool_t,
}Expand description
\brief Frame delivered by the camera.
Fields
buffer: *mut c_void!< Comprises image and potentially chunk data
bufferSize: VmbUint32_t!< The size of the data buffer
context: [*mut c_void; 4]!< 4 void pointers that can be employed by the user (e.g. for storing handles)
receiveStatus: VmbFrameStatus_t!< The resulting status of the receive operation
frameID: VmbUint64_t!< Unique ID of this frame in this stream
timestamp: VmbUint64_t!< The timestamp set by the camera
imageData: *mut VmbUint8_t!< The start of the image data, if present, or null
receiveFlags: VmbFrameFlags_t!< Flags indicating which additional frame information is available
pixelFormat: VmbPixelFormat_t!< Pixel format of the image
width: VmbImageDimension_t!< Width of an image
height: VmbImageDimension_t!< Height of an image
offsetX: VmbImageDimension_t!< Horizontal offset of an image
offsetY: VmbImageDimension_t!< Vertical offset of an image
payloadType: VmbPayloadType_t!< The type of payload
chunkDataPresent: VmbBool_t!< True if the transport layer reported chunk data to be present in the buffer