pub type VmbFrame_t = VmbFrame;Expand description
\brief Frame delivered by the camera.
Aliased Type
#[repr(C)]pub struct VmbFrame_t {Show 15 fields
pub buffer: *mut c_void,
pub bufferSize: u32,
pub context: [*mut c_void; 4],
pub receiveStatus: i32,
pub frameID: u64,
pub timestamp: u64,
pub imageData: *mut u8,
pub receiveFlags: u32,
pub pixelFormat: u32,
pub width: u32,
pub height: u32,
pub offsetX: u32,
pub offsetY: u32,
pub payloadType: u32,
pub chunkDataPresent: u8,
}Fields
buffer: *mut c_void!< Comprises image and potentially chunk data
bufferSize: u32!< The size of the data buffer
context: [*mut c_void; 4]!< 4 void pointers that can be employed by the user (e.g. for storing handles)
receiveStatus: i32!< The resulting status of the receive operation
frameID: u64!< Unique ID of this frame in this stream
timestamp: u64!< The timestamp set by the camera
imageData: *mut u8!< The start of the image data, if present, or null
receiveFlags: u32!< Flags indicating which additional frame information is available
pixelFormat: u32!< Pixel format of the image
width: u32!< Width of an image
height: u32!< Height of an image
offsetX: u32!< Horizontal offset of an image
offsetY: u32!< Vertical offset of an image
payloadType: u32!< The type of payload
chunkDataPresent: u8!< True if the transport layer reported chunk data to be present in the buffer